@@ -1,9 +1,9 @@
 /*
- * tomoyo_file_test.c
+ * ccs_file_test.c
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.3.0+   2011/09/29
+ * Version: 2.4.0   2011/08/06
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -116,17 +116,18 @@ static void stage_file_test(void)
 	{
 		int pipe_fd[2] = { EOF, EOF };
 		int err = 0;
+		int ret_ignored;
 		fflush(stdout);
 		fflush(stderr);
-		pipe(pipe_fd);
+		ret_ignored = pipe(pipe_fd);
 		if (fork() == 0) {
 			execl("/bin/true", "/bin/true", NULL);
 			err = errno;
-			write(pipe_fd[1], &err, sizeof(err));
+			ret_ignored = write(pipe_fd[1], &err, sizeof(err));
 			_exit(0);
 		}
 		close(pipe_fd[1]);
-		read(pipe_fd[0], &err, sizeof(err));
+		ret_ignored = read(pipe_fd[0], &err, sizeof(err));
 		show_prompt("execve()");
 		errno = err;
 		show_result(err ? EOF : 0);
@@ -263,7 +264,6 @@ static void set_file_enforce(int enforce)
 		set_profile(3, "file::mksock");
 		set_profile(3, "file::truncate");
 		set_profile(3, "file::symlink");
-		set_profile(3, "file::rewrite");
 		set_profile(3, "file::mkblock");
 		set_profile(3, "file::mkchar");
 		set_profile(3, "file::link");
@@ -274,7 +274,7 @@ static void set_file_enforce(int enforce)
 		set_profile(3, "file::ioctl");
 		set_profile(3, "file::chroot");
 		set_profile(3, "file::mount");
-		set_profile(3, "file::umount");
+		set_profile(3, "file::unmount");
 		set_profile(3, "file::pivot_root");
 	} else {
 		set_profile(0, "file::execute");
@@ -287,7 +287,6 @@ static void set_file_enforce(int enforce)
 		set_profile(0, "file::mksock");
 		set_profile(0, "file::truncate");
 		set_profile(0, "file::symlink");
-		set_profile(0, "file::rewrite");
 		set_profile(0, "file::mkblock");
 		set_profile(0, "file::mkchar");
 		set_profile(0, "file::link");
@@ -298,14 +297,14 @@ static void set_file_enforce(int enforce)
 		set_profile(0, "file::ioctl");
 		set_profile(0, "file::chroot");
 		set_profile(0, "file::mount");
-		set_profile(0, "file::umount");
+		set_profile(0, "file::unmount");
 		set_profile(0, "file::pivot_root");
 	}
 }
 
 int main(int argc, char *argv[])
 {
-	tomoyo_test_init();
+	ccs_test_init();
 	make_elf_lib();
 
 	printf("***** Testing file hooks in enforce mode. *****\n");
@@ -325,5 +324,9 @@ int main(int argc, char *argv[])
 	creanup_files();
 
 	clear_status();
+	if (0) { /* To suppress "defined but not used" warnings. */
+		write_domain_policy("", 0);
+		write_exception_policy("", 0);
+	}
 	return 0;
 }
